==> haskell-temporary-1.2.1.1-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-temporary.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: temporary
version: 1.2.1.1
id: temporary-1.2.1.1-If5D1glDpYJK2mxUYifVbg
key: temporary-1.2.1.1-If5D1glDpYJK2mxUYifVbg
license: BSD-3-Clause
maintainer: Mateusz Kowalczyk <fuuzetsu@fuuzetsu.co.uk>, Roman Cheplyaka <roma@ro-che.info>
homepage: https://github.com/feuerbach/temporary
synopsis: Portable temporary file and directory support
description:
    Functions for creating temporary files and directories.
category: System, Utils
abi: 4b9f5b2e05663602ff877336bf2cb881
exposed: True
exposed-modules:
    System.IO.Temp
import-dirs: /usr/lib/ghc-8.4.2/site-local/temporary-1.2.1.1
library-dirs: /usr/lib/ghc-8.4.2/site-local/temporary-1.2.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.2/temporary-1.2.1.1
hs-libraries: HStemporary-1.2.1.1-If5D1glDpYJK2mxUYifVbg
depends:
    base-4.11.1.0 filepath-1.4.2 directory-1.3.1.5 transformers-0.5.5.0
    exceptions-0.8.3-Ii5Q7YFckHgBserQRiDSiR unix-2.7.2.2
abi-depends: base-4.11.1.0=ecd125f03c784a67b61c9a8f6dd222e4
             filepath-1.4.2=a70b79acbde9ca897bdc5eadf9254ba7
             directory-1.3.1.5=c4ddb2059d4b7fed7d39b1d1bb3bf41d
             transformers-0.5.5.0=02be5c4dc3fdc926cf1b36bd484a25f8
             exceptions-0.8.3-Ii5Q7YFckHgBserQRiDSiR=9f60f161536a7d4278dffe801494d805
             unix-2.7.2.2=52cd75b8c492339f1bc16a6e08d9b9d7
haddock-interfaces: /usr/share/doc/haskell-temporary/html/temporary.haddock
haddock-html: /usr/share/doc/haskell-temporary/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-temporary-1.2.1.1-8-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-temporary.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: temporary
version: 1.2.1.1
id: temporary-1.2.1.1-95fbnHEC7nq17wAceUPLcX
key: temporary-1.2.1.1-95fbnHEC7nq17wAceUPLcX
license: BSD-3-Clause
maintainer: Mateusz Kowalczyk <fuuzetsu@fuuzetsu.co.uk>, Roman Cheplyaka <roma@ro-che.info>
homepage: https://github.com/feuerbach/temporary
synopsis: Portable temporary file and directory support
description:
    Functions for creating temporary files and directories.
category: System, Utils
abi: f0b995b96e19e60c8d5d576d813062b5
exposed: True
exposed-modules:
    System.IO.Temp
import-dirs: /usr/lib/ghc-8.4.2/site-local/temporary-1.2.1.1
library-dirs: /usr/lib/ghc-8.4.2/site-local/temporary-1.2.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.2/temporary-1.2.1.1
hs-libraries: HStemporary-1.2.1.1-95fbnHEC7nq17wAceUPLcX
depends:
    base-4.11.1.0 filepath-1.4.2 directory-1.3.1.5 transformers-0.5.5.0
    exceptions-0.8.3-6WkrztLwxRv2NB3qEvHVbf unix-2.7.2.2
abi-depends: base-4.11.1.0=ecd125f03c784a67b61c9a8f6dd222e4
             filepath-1.4.2=a70b79acbde9ca897bdc5eadf9254ba7
             directory-1.3.1.5=c4ddb2059d4b7fed7d39b1d1bb3bf41d
             transformers-0.5.5.0=02be5c4dc3fdc926cf1b36bd484a25f8
             exceptions-0.8.3-6WkrztLwxRv2NB3qEvHVbf=90dd74da021381146ba64944278df775
             unix-2.7.2.2=52cd75b8c492339f1bc16a6e08d9b9d7
haddock-interfaces: /usr/share/doc/haskell-temporary/html/temporary.haddock
haddock-html: /usr/share/doc/haskell-temporary/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
